@@ -26,11 +26,12 @@ from rdflib import (
     URIRef,
     XSD,
 )
+from skolemizer import Skolemizer
 import validators
 
 from modelldcatnotordf.document import FoafDocument
 from modelldcatnotordf.licensedocument import LicenseDocument
-from modelldcatnotordf.skolemizer import Skolemizer
+
 
 DCAT = Namespace("http://www.w3.org/ns/dcat#")
 ODRL = Namespace("http://www.w3.org/ns/odrl/2/")
@@ -2388,8 +2389,10 @@ class DataType(ModelElement):
     _g: Graph
     _belongs_to_module: List[str]
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
 
     def to_rdf(
@@ -2435,8 +2438,10 @@ class RootObjectType(ModelElement):
     _g: Graph
     _belongs_to_module: List[str]
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
 
     def to_rdf(
@@ -2493,8 +2498,10 @@ class CodeList(ModelElement):
     _code_list_reference: Union[CodeList, URI]
     _belongs_to_module: List[str]
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
 
     @property
@@ -2613,8 +2620,10 @@ class CodeElement:
     _next_element: Union[CodeElement, URI]
     _previous_element: Union[CodeElement, URI]
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         self._type = MODELLDCATNO.CodeElement
 
     @property
@@ -3057,8 +3066,10 @@ class Note(ModelProperty):
         """Set for property_note."""
         self._property_note = property_note
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
 
     def to_rdf(
